@@ -1,20 +1,28 @@
-( cd opt/kde/share/doc/HTML/sv/kchart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kchart ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kformula ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kformula ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kexi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kexi ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kivio ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kivio ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/koffice ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/koffice ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/koshell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/koshell ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kpresenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kpresenter ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kspread ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kspread ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/krita ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/krita ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kugar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kugar ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kword ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kword ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/koffice ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/koffice ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/koshell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/koshell ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kspread ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kspread ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/karbon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/karbon ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kchart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kchart ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kpresenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kpresenter ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kplato ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kplato ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/thesaurus ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/thesaurus ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kformula ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kformula ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
